libgo/runtime: Fix signal stack size for ia64

Andreas Schwab schwab@suse.de
Wed Aug 31 08:24:00 GMT 2016


On ia64, MINSIGSTKSZ is 128K.

Andreas.

	* libgo/runtime/runtime.c (runtime_mpreinit): Increase stack size to
	128K.
---
 libgo/runtime/runtime.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/libgo/runtime/runtime.c b/libgo/runtime/runtime.c
index c7d33bc..e8eb957 100644
--- a/libgo/runtime/runtime.c
+++ b/libgo/runtime/runtime.c
@@ -272,7 +272,7 @@ runtime_tickspersecond(void)
 void
 runtime_mpreinit(M *mp)
 {
-	mp->gsignal = runtime_malg(32*1024, (byte**)&mp->gsignalstack, &mp->gsignalstacksize);	// OS X wants >=8K, Linux >=2K
+	mp->gsignal = runtime_malg(128*1024, (byte**)&mp->gsignalstack, &mp->gsignalstacksize);	// OS X wants >=8K, Linux >=2K, ia64 >=128K
 	mp->gsignal->m = mp;
 }
 
-- 
2.9.3

-- 
Andreas Schwab, SUSE Labs, schwab@suse.de
GPG Key fingerprint = 0196 BAD8 1CE9 1970 F4BE  1748 E4D4 88E3 0EEA B9D7
"And now for something completely different."



More information about the Gcc-patches mailing list